==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Modify/Offset/ts/Offset_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja_JP">
<context>
    <name>Offset</name>
    <message>
        <source>Choose line, arc or circle</source>
        <translation type="obsolete">線分、弧、円を選択</translation>
    </message>
    <message>
        <location filename="../Offset.ui" line="+17"/>
        <source>&amp;Distance:</source>
        <translation>&amp;D 距離:</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>&amp;Number:</source>
        <translation>&amp;N 数:</translation>
    </message>
    <message>
        <source>Para&amp;llel (with Distance)</source>
        <translation type="obsolete">&amp;l 平行線（距離指定）</translation>
    </message>
    <message>
        <location filename="../OffsetInit.js" line="+2"/>
        <source>Offset (with Distance)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Offset line, arc, circle or ellipse</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Draw parallel to existing line or concentric arc, circle</source>
        <translation type="vanished">既存の線分または弧、円との平行線を描画</translation>
    </message>
    <message>
        <location filename="../Offset.js" line="+75"/>
        <source>Choose line, arc, circle or ellipse</source>
        <translation>線分,弧,円または楕円を選択してください</translation>
    </message>
    <message>
        <location line="+89"/>
        <source>Radius dropped below 0.0 after %1 concentric circle(s).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Radius dropped below 0.0 after %1 concentric arc(s).</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Modify/Offset/ts/Offset_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>Offset</name>
    <message>
        <source>Choose line, arc or circle</source>
        <translation type="obsolete">線分、弧、円を選択</translation>
    </message>
    <message>
        <location filename="../Offset.ui" line="+17"/>
        <source>&amp;Distance:</source>
        <translation>&amp;D 距離:</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>&amp;Number:</source>
        <translation>&amp;N 数:</translation>
    </message>
    <message>
        <source>Para&amp;llel (with Distance)</source>
        <translation type="obsolete">&amp;l 平行線（距離指定）</translation>
    </message>
    <message>
        <location filename="../OffsetInit.js" line="+2"/>
        <source>Offset (with Distance)</source>
        <translation>オフセット（距離）</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Offset line, arc, circle or ellipse</source>
        <translation>オフセット 線分、弧、円または楕円</translation>
    </message>
    <message>
        <source>Draw parallel to existing line or concentric arc, circle</source>
        <translation type="vanished">既存の線分または弧、円との平行線を描画</translation>
    </message>
    <message>
        <location filename="../Offset.js" line="+75"/>
        <source>Choose line, arc, circle or ellipse</source>
        <translation>線分,弧,円または楕円を選択してください</translation>
    </message>
    <message numerus="yes">
        <location line="+89"/>
        <source>Radius dropped below 0.0 after %n concentric circle(s).</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location line="+3"/>
        <source>Radius dropped below 0.0 after %n concentric arc(s).</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Radius dropped below 0.0 after %1 concentric circle(s).</source>
        <translation type="vanished">同心円の半径が%1から0.0を下回りました。</translation>
    </message>
    <message>
        <source>Radius dropped below 0.0 after %1 concentric arc(s).</source>
        <translation type="vanished">同心弧の半径が%1から0.0を下回りました。 </translation>
    </message>
</context>
</TS>
